#!/usr/bin/env python

import requests
import re
import anyjson



def get_balance(number, password):
    s = requests.Session()

    response = s.get('https://login.mts.ru/amserver/UI/Login')
    csrf_sign = re.search(r'name="csrf.sign" value="(.*?)"', response.content).group(1)

    response = s.post('https://login.mts.ru/amserver/UI/Login?service=lk&goto=https://lk.ssl.mts.ru/',
                      data={'IDToken1': number,
                            'IDToken2': password,
                            'csrf.sign': csrf_sign,
                        },
                      headers={
                          'Accept-Language': 'ru,en;q=0.8',
                      })

    data = anyjson.deserialize(s.get('https://lk.ssl.mts.ru/ProfileStub/PAGet').content)
    return data.get('Balance')



#!/usr/bin/env python

"""Mobile Balance.

Usage:
  mobile-balance <operator> --phone=<phone-number> --password=<password>
  mobile-balance (-h | --help)
  mobile-balance --version

Options:
  -h --help                Show this screen.
  --version                Show version.
  --phone=<phone-number>  Mobile number without 8 or +7 prefix.
  --password=<password>    Password from personal profile at mobile operator's site.

"""

from mobile_balance import mts, megafon, tele2
from docopt import docopt


def main():
    arguments = docopt(__doc__, version='Mobile Balance 0.3.0')
    mobile_operator = globals()[arguments['<operator>']]
    print mobile_operator.get_balance(arguments['--phone'],
                                      arguments['--password'])



import requests
import re
import anyjson


def get_balance(number, password):
    s = requests.Session()

    response = s.get('https://lk.megafon.ru/login/')
    csrf_token = re.search(r'name=CSRF value="(.*?)"', response.content).group(1)

    response = s.post('https://lk.megafon.ru/dologin/',
                      data={'j_username': number,
                            'j_password': password,
                            'CSRF': csrf_token,
                        })

    content = s.get('https://lk.megafon.ru/').content
    match = re.search(r'<div class="[^"]*ui-label-balance".*?([\d,]+).*?</div>',
                      content)
    return match.group(1).replace(',', '.')
